# Yostate

Yostate — Yet another State Machine Framework — фреймворк для создания на Python сложных стейт-машин с памятью. Подходит для написания потоковых парсеров, кнопочных чат-ботов, алгоритма заливки больших файлов в облако.

Yostate делает упор на возможность сериализовать данные стейт-машины в БД, а затем восстановить её работу с места остановки.

## Документация к микрофреймворку

- [Сущности с примерам](./concepts.yaml)


## Чем краулер отличается от стейт-машины

[![](crawler_vs_state_machine.drawio.png)](crawler_vs_state_machine.drawio.png)
